# THIRD-PARTY LICENSES

This project includes third-party libraries and components, licensed under their respective open source licenses.

| Component          | Version | License    | URL                                                          |
|--------------------|---------|------------|--------------------------------------------------------------|
| langchain-core     | >=1.0   | MIT        | https://github.com/langchain-ai/langchain                    |
| opendataloader-pdf | >=2.0.0 | Apache-2.0 | https://github.com/opendataloader-project/opendataloader-pdf |
